<?php
/**
 * @copyright	Copyright (C) 2005 - 2012 Open Source Matters, Inc & Szarlej
 * @license		GNU General Public License version 2 or later; see LICENSE.txt
 */

/**
 * be-BY localise class
 *
 * @package		Joomla.Site
 * @since		1.6
 */
abstract class be_BYLocalise
{
	/**
	 * Returns the potential suffixes for a specific number of items
	 *
	 * @param	int $count  The number of items.
	 * @return	array  An array of potential suffixes.
	 * @since	1.6
	 */
	public static function getPluralSuffixes($count)
	{
		if ($count == 0) {
			$return = array('0');
		} else {
			$return = array(($count%10==1 && $count%100!=11 ? '1' : ($count%10>=2 && $count%10<=4 && ($count%100<10 || $count%100>=20) ? '2' : 'MORE')));
		}
		return $return;
	}

	public static function transliterate($string)
	{
		$str = JString::strtolower($string);

		$glyph_array = array(
			'a' => 'а',
			'b' => 'б',
			'v' => 'в',
			'g' => 'г,ґ',
			'd' => 'д',
			'e' => 'е,є,э',
			'jo' => 'ё',
			'zh' => 'ж',
			'z' => 'з',
			'i' => 'и,і',
			'ji' => 'ї',
			'j' => 'й',
			'k' => 'к',
			'l' => 'л',
			'm' => 'м',
			'n' => 'н',
			'o' => 'о',
			'p' => 'п',
			'r' => 'р',
			's' => 'с',
			't' => 'т',
			'u' => 'у,ў',
			'f' => 'ф',
			'kh' => 'х',
			'ts' => 'ц',
			'ch' => 'ч',
			'sh' => 'ш',
			'shch' => 'щ',
			'' => 'ъ,\'',
			'y' => 'ы',
			'' => 'ь',
			'yu' => 'ю',
			'ya' => 'я',
		);

		foreach ($glyph_array as $letter => $glyphs) {
			$glyphs = explode(',', $glyphs);
			$str = str_replace($glyphs, $letter, $str);
		}

		$str = preg_replace('#\&\#?[a-z0-9]+\;#ismu', '', $str);

		return $str;
	}

	/**
	 * Returns the ignored search words
	 *
	 * @return	array  An array of ignored search words.
	 * @since	1.6
	 */
	public static function getIgnoredSearchWords()
	{
		  $search_ignore = array();
		  $search_ignore[] = 'href';
			$search_ignore[] = 'lol';
			$search_ignore[] = 'www';
			$search_ignore[] = 'а';
			$search_ignore[] = 'без';
			$search_ignore[] = 'дзякую';
			$search_ignore[] = 'дзякуючы';
			$search_ignore[] = 'блізка';
			$search_ignore[] = 'больш';
			$search_ignore[] = 'больш-менш';
			$search_ignore[] = 'вялікая';
			$search_ignore[] = 'вялікія';
			$search_ignore[] = 'вялікае';
			$search_ignore[] = 'вялікі';
			$search_ignore[] = 'будзе';
			$search_ignore[] = 'будуць';
			$search_ignore[] = 'быўшы';
			$search_ignore[] = 'быў';
			$search_ignore[] = 'была';
			$search_ignore[] = 'былі';
			$search_ignore[] = 'было';
			$search_ignore[] = 'быць';
			$search_ignore[] = 'у';
			$search_ignore[] = 'ў';
			$search_ignore[] = 'вас';
			$search_ignore[] = 'вам';
			$search_ignore[] = 'вамі';
			$search_ignore[] = 'ваш';
			$search_ignore[] = 'ваша';
			$search_ignore[] = 'ваша';
			$search_ignore[] = 'вашага';
			$search_ignore[] = 'вашай';
			$search_ignore[] = 'вашым';
			$search_ignore[] = 'вашаму';
			$search_ignore[] = 'вашыя';
			$search_ignore[] = 'вашым';
			$search_ignore[] = 'вашымі';
			$search_ignore[] = 'вашых';
			$search_ignore[] = 'вашу';
			$search_ignore[] = 'паблізу';
			$search_ignore[] = 'бо';
			$search_ignore[] = 'заўсёды';
			$search_ignore[] = 'усюды';
			$search_ignore[] = 'ўсюды';
			$search_ignore[] = 'пышна';
			$search_ignore[] = 'па-за';
			$search_ignore[] = 'ўнутры';
			$search_ignore[] = 'унутры';
			$search_ignore[] = 'каля';
			$search_ignore[] = 'вось';
			$search_ignore[] = 'часамі';
			$search_ignore[] = 'часам';
			$search_ignore[] = 'часу';
			$search_ignore[] = 'час';
			$search_ignore[] = 'усё';
			$search_ignore[] = 'усё-такі';
			$search_ignore[] = 'усяго';
			$search_ignore[] = 'усяго';
			$search_ignore[] = 'усімі';
			$search_ignore[] = 'усімі';
			$search_ignore[] = 'усіх';
			$search_ignore[] = 'усякая';
			$search_ignore[] = 'усякую';
			$search_ignore[] = 'усякія';
			$search_ignore[] = 'усякі';
			$search_ignore[] = 'усякім';
			$search_ignore[] = 'усякімі';
			$search_ignore[] = 'усякіх';
			$search_ignore[] = 'усякага';
			$search_ignore[] = 'усякае';
			$search_ignore[] = 'усякай';
			$search_ignore[] = 'усякім';
			$search_ignore[] = 'ўсё';
			$search_ignore[] = 'ўсё-такі';
			$search_ignore[] = 'ўсяго';
			$search_ignore[] = 'ўсяго';
			$search_ignore[] = 'ўсімі';
			$search_ignore[] = 'ўсімі';
			$search_ignore[] = 'ўсіх';
			$search_ignore[] = 'ўсякая';
			$search_ignore[] = 'ўсякую';
			$search_ignore[] = 'ўсякія';
			$search_ignore[] = 'ўсякі';
			$search_ignore[] = 'ўсякім';
			$search_ignore[] = 'ўсякімі';
			$search_ignore[] = 'ўсякіх';
			$search_ignore[] = 'ўсякага';
			$search_ignore[] = 'ўсякае';
			$search_ignore[] = 'ўсякай';
			$search_ignore[] = 'ўсякім';
			$search_ignore[] = 'кожнаму';
			$search_ignore[] = 'выглядае';
			$search_ignore[] = 'выглядаюць';
			$search_ignore[] = 'дзе';
			$search_ignore[] = 'ды';
			$search_ignore[] = 'далёка';
			$search_ignore[] = 'сапраўды';
			$search_ignore[] = 'дзень';
			$search_ignore[] = 'для';
			$search_ignore[] = 'дне';
			$search_ignore[] = 'дзён';
			$search_ignore[] = 'днём';
			$search_ignore[] = 'днём';
			$search_ignore[] = 'дні';
			$search_ignore[] = 'дню';
			$search_ignore[] = 'дня';
			$search_ignore[] = 'днях';
			$search_ignore[] = 'днямі';
			$search_ignore[] = 'днях';
			$search_ignore[] = 'да';
			$search_ignore[] = 'так';
			$search_ignore[] = 'яго';
			$search_ignore[] = 'яе';
			$search_ignore[] = 'калі';
			$search_ignore[] = 'ёсць';
			$search_ignore[] = 'яшчэ';
			$search_ignore[] = 'ж';
			$search_ignore[] = 'за';
			$search_ignore[] = 'навошта';
			$search_ignore[] = 'затым';
			$search_ignore[] = 'захацеў';
			$search_ignore[] = 'захацела';
			$search_ignore[] = 'захацелі';
			$search_ignore[] = 'захачу';
			$search_ignore[] = 'ведае';
			$search_ignore[] = 'ведаў';
			$search_ignore[] = 'ведала';
			$search_ignore[] = 'ведалі';
			$search_ignore[] = 'ведала';
			$search_ignore[] = 'ведаю';
			$search_ignore[] = 'і';
		  $search_ignore[] = 'і г.д';
			$search_ignore[] = 'і т.п';
			$search_ignore[] = 'бо';
			$search_ignore[] = 'з';
			$search_ignore[] = 'з-пад';
			$search_ignore[] = 'ці';
			$search_ignore[] = 'інакш';
			$search_ignore[] = 'часам';
			$search_ignore[] = 'шукаў';
			$search_ignore[] = 'шукала';
			$search_ignore[] = 'шукалі';
			$search_ignore[] = 'шукала';
			$search_ignore[] = 'шукаць';
			$search_ignore[] = 'ім';
			$search_ignore[] = 'імхо';
			$search_ignore[] = 'дык вось;';
			$search_ignore[] = 'іх';
			$search_ignore[] = 'да';
			$search_ignore[] = 'кожны';
			$search_ignore[] = 'як';
			$search_ignore[] = 'якая';
			$search_ignore[] = 'якія';
			$search_ignore[] = 'якім';
			$search_ignore[] = 'якіх';
			$search_ignore[] = 'якога';
			$search_ignore[] = 'якое';
			$search_ignore[] = 'які';
			$search_ignore[] = 'якім';
			$search_ignore[] = 'якому';
			$search_ignore[] = 'якую';
			$search_ignore[] = 'кім';
			$search_ignore[] = 'калі';
			$search_ignore[] = 'калі-небудзь';
			$search_ignore[] = 'каго';
			$search_ignore[] = 'кім';
			$search_ignore[] = 'каму';
			$search_ignore[] = 'якая';
			$search_ignore[] = 'якога';
			$search_ignore[] = 'якое';
			$search_ignore[] = 'якой';
			$search_ignore[] = 'якім';
			$search_ignore[] = 'якому';
			$search_ignore[] = 'якую';
			$search_ignore[] = 'якія';
			$search_ignore[] = 'які';
			$search_ignore[] = 'якім';
			$search_ignore[] = 'якіх';
			$search_ignore[] = 'хто';
			$search_ignore[] = 'хто-то';
			$search_ignore[] = 'дарэчы';
			$search_ignore[] = 'куды';
			$search_ignore[] = 'ці';
			$search_ignore[] = 'альбо';
			$search_ignore[] = 'лол';
			$search_ignore[] = 'лепшая';
			$search_ignore[] = 'лепшае';
			$search_ignore[] = 'лепшыя';
			$search_ignore[] = 'лепшы';
			$search_ignore[] = 'любая';
			$search_ignore[] = 'любога';
			$search_ignore[] = 'любое';
			$search_ignore[] = 'любы';
			$search_ignore[] = 'любому';
			$search_ignore[] = 'любую';
			$search_ignore[] = 'любыя';
			$search_ignore[] = 'любым';
			$search_ignore[] = 'любымі';
			$search_ignore[] = 'любых';
			$search_ignore[] = 'маленькая';
			$search_ignore[] = 'маленькі';
			$search_ignore[] = 'маленькім';
			$search_ignore[] = 'маленькага';
			$search_ignore[] = 'маленькае';
			$search_ignore[] = 'маленькай';
			$search_ignore[] = 'маленькім';
			$search_ignore[] = 'маленькаму';
			$search_ignore[] = 'маленькую';
			$search_ignore[] = 'паміж';
			$search_ignore[] = 'менш';
			$search_ignore[] = 'менш';
			$search_ignore[] = 'мяне';
			$search_ignore[] = 'свет';
			$search_ignore[] = 'мне';
			$search_ignore[] = 'шмат';
			$search_ignore[] = 'мной';
			$search_ignore[] = 'мог';
			$search_ignore[] = 'магла';
			$search_ignore[] = 'маглі';
			$search_ignore[] = 'магло';
			$search_ignore[] = 'магу';
			$search_ignore[] = 'маё';
			$search_ignore[] = 'можам';
			$search_ignore[] = 'можа';
			$search_ignore[] = 'мае';
			$search_ignore[] = 'мой';
			$search_ignore[] = 'мая';
			$search_ignore[] = 'мы';
			$search_ignore[] = 'на';
			$search_ignore[] = 'над';
			$search_ignore[] = 'таму';
			$search_ignore[] = 'найбольш';
			$search_ignore[] = 'найменш';
			$search_ignore[] = 'напіша';
			$search_ignore[] = 'напішу';
			$search_ignore[] = 'напішуць';
			$search_ignore[] = 'напрыклад';
			$search_ignore[] = 'нас';
			$search_ignore[] = 'нам';
			$search_ignore[] = 'намі';
			$search_ignore[] = 'наш';
			$search_ignore[] = 'наша';
			$search_ignore[] = 'наша';
			$search_ignore[] = 'нашага';
			$search_ignore[] = 'нашай';
			$search_ignore[] = 'нашым';
			$search_ignore[] = 'нашаму';
			$search_ignore[] = 'нашы';
			$search_ignore[] = 'нашым';
			$search_ignore[] = 'нашымі';
			$search_ignore[] = 'нашых';
			$search_ignore[] = 'нашу';
			$search_ignore[] = 'не';
		  $search_ignore[] = 'яго';
			$search_ignore[] = 'нядаўна';
			$search_ignore[] = 'няўжо';
			$search_ignore[] = 'яе';
			$search_ignore[] = 'яе';
			$search_ignore[] = 'трохі';
			$search_ignore[] = 'няма';
			$search_ignore[] = 'ні';
			$search_ignore[] = 'ніколі';
			$search_ignore[] = 'ніхто';
			$search_ignore[] = 'нішто';
			$search_ignore[] = 'ім';
			$search_ignore[] = 'нічога';
			$search_ignore[] = 'але';
			$search_ignore[] = 'новая';
			$search_ignore[] = 'новага';
			$search_ignore[] = 'новае';
			$search_ignore[] = 'новай';
			$search_ignore[] = 'новым';
			$search_ignore[] = 'новаму';
			$search_ignore[] = 'навін';
			$search_ignore[] = 'навіны';
			$search_ignore[] = 'навіна';
			$search_ignore[] = 'навінамі';
			$search_ignore[] = 'новую';
			$search_ignore[] = 'новы';
			$search_ignore[] = 'новы';
			$search_ignore[] = 'новым';
			$search_ignore[] = 'новых';
			$search_ignore[] = 'новых';
			$search_ignore[] = 'ну';
			$search_ignore[] = 'патрэбен';
			$search_ignore[] = 'патрэбна';
			$search_ignore[] = 'трэба';
			$search_ignore[] = 'патрэбныя';
			$search_ignore[] = 'аб';
			$search_ignore[] = 'аб';
			$search_ignore[] = 'аднак';
			$search_ignore[] = 'каля';
			$search_ignore[] = 'ён';
			$search_ignore[] = 'яна';
			$search_ignore[] = 'яны';
			$search_ignore[] = 'яно';
			$search_ignore[] = 'ад';
			$search_ignore[] = 'адказ';
			$search_ignore[] = 'адказаў';
			$search_ignore[] = 'адказала';
			$search_ignore[] = 'адказалі';
			$search_ignore[] = 'адказала';
			$search_ignore[] = 'адкуль';
			$search_ignore[] = 'зусім';
			$search_ignore[] = 'перад';
			$search_ignore[] = 'пісаў';
			$search_ignore[] = 'пісала';
			$search_ignore[] = 'пісалі';
			$search_ignore[] = 'пісала';
			$search_ignore[] = 'піша';
			$search_ignore[] = 'пішу';
			$search_ignore[] = 'пішуць';
			$search_ignore[] = 'дрэнна';
			$search_ignore[] = 'па';
			$search_ignore[] = 'паблізу';
			$search_ignore[] = 'пад';
			$search_ignore[] = 'калі ласка';
			$search_ignore[] = 'атрымлівала';
			$search_ignore[] = 'атрымлівалі';
			$search_ignore[] = 'атрымлівала';
			$search_ignore[] = 'атрымліваць';
			$search_ignore[] = 'атрымаў';
			$search_ignore[] = 'атрымала';
			$search_ignore[] = 'атрымалі';
			$search_ignore[] = 'атрымала';
			$search_ignore[] = 'атрымаць';
			$search_ignore[] = 'часу';
			$search_ignore[] = 'пара';
			$search_ignore[] = 'сітавінам';
			$search_ignore[] = 'порамі';
			$search_ignore[] = 'часу';
			$search_ignore[] = 'часам';
			$search_ignore[] = 'пару';
			$search_ignore[] = 'пары';
			$search_ignore[] = 'пасля';
			$search_ignore[] = 'таму';
			$search_ignore[] = 'чаму';
			$search_ignore[] = 'амаль';
			$search_ignore[] = 'пайшлі';
			$search_ignore[] = 'праўда';
			$search_ignore[] = 'перш';
			$search_ignore[] = 'прыкладна';
			$search_ignore[] = 'пра';
			$search_ignore[] = 'проста';
			$search_ignore[] = 'прайшоў';
			$search_ignore[] = 'прайшоў';
			$search_ignore[] = 'прайшла';
			$search_ignore[] = 'прайшлі';
			$search_ignore[] = 'прайшло';
			$search_ignore[] = 'няхай';
			$search_ignore[] = 'няхай';
			$search_ignore[] = 'раз';
			$search_ignore[] = 'разы';
			$search_ignore[] = 'хіба';
		  $search_ignore[] = 'радзей';
		  $search_ignore[] = 'з';
			$search_ignore[] = 'сам';
			$search_ignore[] = 'сама';
			$search_ignore[] = 'самі';
			$search_ignore[] = 'самім';
			$search_ignore[] = 'самімі';
			$search_ignore[] = 'саміх';
			$search_ignore[] = 'само';
			$search_ignore[] = 'самога';
			$search_ignore[] = 'самае';
			$search_ignore[] = 'самой';
			$search_ignore[] = 'самім';
			$search_ignore[] = 'самому';
			$search_ignore[] = 'само';
			$search_ignore[] = 'саму';
			$search_ignore[] = 'самую';
			$search_ignore[] = 'самыя';
			$search_ignore[] = 'самы';
			$search_ignore[] = 'самым';
			$search_ignore[] = 'самымі';
			$search_ignore[] = 'самых';
			$search_ignore[] = 'зрабіў';
			$search_ignore[] = 'зрабіла';
			$search_ignore[] = 'зрабілі';
			$search_ignore[] = 'зрабіла';
			$search_ignore[] = 'зараз';
			$search_ignore[] = 'скрозь';
			$search_ignore[] = 'хутчэй';
			$search_ignore[] = 'хутка';
			$search_ignore[] = 'выпадку';
			$search_ignore[] = 'выпадкам';
			$search_ignore[] = 'выпадак';
			$search_ignore[] = 'нагоды';
			$search_ignore[] = 'выпадку';
			$search_ignore[] = 'гледзячы';
			$search_ignore[] = 'са';
			$search_ignore[] = 'зусім';
			$search_ignore[] = 'дзякуй';
			$search_ignore[] = 'старая';
			$search_ignore[] = 'старога';
			$search_ignore[] = 'старыя';
			$search_ignore[] = 'старой';
			$search_ignore[] = 'старым';
			$search_ignore[] = 'старому';
			$search_ignore[] = 'старую';
			$search_ignore[] = 'стары';
			$search_ignore[] = 'старым';
			$search_ignore[] = 'старых';
			$search_ignore[] = 'так';
			$search_ignore[] = 'таксама';
			$search_ignore[] = 'тваё';
			$search_ignore[] = 'твайго';
			$search_ignore[] = 'тваё';
			$search_ignore[] = 'твае';
			$search_ignore[] = 'твой';
			$search_ignore[] = 'тваю';
			$search_ignore[] = 'твая';
			$search_ignore[] = 'тыя';
			$search_ignore[] = 'цябе';
			$search_ignore[] = 'тым';
			$search_ignore[] = 'тымі';
			$search_ignore[] = 'зараз';
			$search_ignore[] = 'тых';
			$search_ignore[] = 'табой';
			$search_ignore[] = 'тады';
			$search_ignore[] = 'таго';
			$search_ignore[] = 'таксама';
			$search_ignore[] = 'той';
			$search_ignore[] = 'толькі';
			$search_ignore[] = 'туды';
			$search_ignore[] = 'у';
			$search_ignore[] = 'жудасна';
			$search_ignore[] = 'ужо';
			$search_ignore[] = 'пазнае';
			$search_ignore[] = 'пазнаюць';
			$search_ignore[] = 'сышоў';
			$search_ignore[] = 'сышоў';
			$search_ignore[] = 'сышла';
			$search_ignore[] = 'сышлі';
			$search_ignore[] = 'сышло';
			$search_ignore[] = 'хадзіў';
			$search_ignore[] = 'хадзіла';
			$search_ignore[] = 'хадзілі';
			$search_ignore[] = 'хадзіла';
			$search_ignore[] = 'ходзіць';
			$search_ignore[] = 'хадзіць';
			$search_ignore[] = 'ходзяць';
			$search_ignore[] = 'добра';
			$search_ignore[] = 'хацеў';
			$search_ignore[] = 'хацела';
			$search_ignore[] = 'хацелі';
			$search_ignore[] = 'хацела';
			$search_ignore[] = 'хоць';
			$search_ignore[] = 'хачу';
			$search_ignore[] = 'часцей';
			$search_ignore[] = 'чаго';
			$search_ignore[] = 'чым';
			$search_ignore[] = 'чым';
			$search_ignore[] = 'чымсьці';
			$search_ignore[] = 'чымсьці';
			$search_ignore[] = 'чаму';
			$search_ignore[] = 'праз';
			$search_ignore[] = 'што';
			$search_ignore[] = 'каб';
			$search_ignore[] = 'каб';
			$search_ignore[] = 'чыё';
			$search_ignore[] = 'чыё';
			$search_ignore[] = 'чыёй';
			$search_ignore[] = 'чыім';
			$search_ignore[] = 'чые';
			$search_ignore[] = 'чыім';
			$search_ignore[] = 'чыімі';
			$search_ignore[] = 'чыіх';
			$search_ignore[] = 'чыя';
			$search_ignore[] = 'ішоў';
			$search_ignore[] = 'ішоў';
			$search_ignore[] = 'ішла';
			$search_ignore[] = 'ішлі';
			$search_ignore[] = 'ішло';
			$search_ignore[] = 'гэтая';
			$search_ignore[] = 'гэтыя';
			$search_ignore[] = 'гэтым';
			$search_ignore[] = 'гэтых';
			$search_ignore[] = 'гэта';
			$search_ignore[] = 'гэтай';
			$search_ignore[] = 'гэтаму';
			$search_ignore[] = 'гэты';
			$search_ignore[] = 'гэтую';
			$search_ignore[] = 'я';
			$search_ignore[] = 'з\'яўляецца';
			$search_ignore[] = 'з\'яўляюцца';

		  return $search_ignore;
	}

	/**
	 * Returns the lower length limit of search words
	 *
	 * @return	integer  The lower length limit of search words.
	 * @since	1.6
	 */
	public static function getLowerLimitSearchWord()
	{
		return 3;
	}

	/**
	 * Returns the upper length limit of search words
	 *
	 * @return	integer  The upper length limit of search words.
	 * @since	1.6
	 */
	public static function getUpperLimitSearchWord()
	{
		return 20;
	}

	/**
	 * Returns the number of chars to display when searching
	 *
	 * @return	integer  The number of chars to display when searching.
	 * @since	1.6
	 */
	public static function getSearchDisplayedCharactersNumber()
	{
		return 200;
	}
}

